# This file was automatically generated by SWIG (http://www.swig.org).
# Version 3.0.12
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
if _swig_python_version_info >= (2, 7, 0):
    def swig_import_helper():
        import importlib
        pkg = __name__.rpartition('.')[0]
        mname = '.'.join((pkg, '_medfile')).lstrip('.')
        try:
            return importlib.import_module(mname)
        except ImportError:
            return importlib.import_module('_medfile')
    _medfile = swig_import_helper()
    del swig_import_helper
elif _swig_python_version_info >= (2, 6, 0):
    def swig_import_helper():
        from os.path import dirname
        import imp
        fp = None
        try:
            fp, pathname, description = imp.find_module('_medfile', [dirname(__file__)])
        except ImportError:
            import _medfile
            return _medfile
        try:
            _mod = imp.load_module('_medfile', fp, pathname, description)
        finally:
            if fp is not None:
                fp.close()
        return _mod
    _medfile = swig_import_helper()
    del swig_import_helper
else:
    import _medfile
del _swig_python_version_info

try:
    _swig_property = property
except NameError:
    pass  # Python < 2.2 doesn't have 'property'.

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_setattr_nondynamic(self, class_type, name, value, static=1):
    if (name == "thisown"):
        return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name, None)
    if method:
        return method(self, value)
    if (not static):
        if _newclass:
            object.__setattr__(self, name, value)
        else:
            self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)


def _swig_setattr(self, class_type, name, value):
    return _swig_setattr_nondynamic(self, class_type, name, value, 0)


def _swig_getattr(self, class_type, name):
    if (name == "thisown"):
        return self.this.own()
    method = class_type.__swig_getmethods__.get(name, None)
    if method:
        return method(self)
    raise AttributeError("'%s' object has no attribute '%s'" % (class_type.__name__, name))


def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except __builtin__.Exception:
    class _object:
        pass
    _newclass = 0

class SwigPyIterator_medfile(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, SwigPyIterator_medfile, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, SwigPyIterator_medfile, name)

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _medfile.delete_SwigPyIterator_medfile
    __del__ = lambda self: None

    def value(self) -> "PyObject *":
        return _medfile.SwigPyIterator_medfile_value(self)

    def incr(self, n: 'size_t'=1) -> "swig::SwigPyIterator_medfile *":
        return _medfile.SwigPyIterator_medfile_incr(self, n)

    def decr(self, n: 'size_t'=1) -> "swig::SwigPyIterator_medfile *":
        return _medfile.SwigPyIterator_medfile_decr(self, n)

    def distance(self, x: 'SwigPyIterator_medfile') -> "ptrdiff_t":
        return _medfile.SwigPyIterator_medfile_distance(self, x)

    def equal(self, x: 'SwigPyIterator_medfile') -> "bool":
        return _medfile.SwigPyIterator_medfile_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator_medfile *":
        return _medfile.SwigPyIterator_medfile_copy(self)

    def next(self) -> "PyObject *":
        return _medfile.SwigPyIterator_medfile_next(self)

    def __next__(self) -> "PyObject *":
        return _medfile.SwigPyIterator_medfile___next__(self)

    def previous(self) -> "PyObject *":
        return _medfile.SwigPyIterator_medfile_previous(self)

    def advance(self, n: 'ptrdiff_t') -> "swig::SwigPyIterator_medfile *":
        return _medfile.SwigPyIterator_medfile_advance(self, n)

    def __eq__(self, x: 'SwigPyIterator_medfile') -> "bool":
        return _medfile.SwigPyIterator_medfile___eq__(self, x)

    def __ne__(self, x: 'SwigPyIterator_medfile') -> "bool":
        return _medfile.SwigPyIterator_medfile___ne__(self, x)

    def __iadd__(self, n: 'ptrdiff_t') -> "swig::SwigPyIterator_medfile &":
        return _medfile.SwigPyIterator_medfile___iadd__(self, n)

    def __isub__(self, n: 'ptrdiff_t') -> "swig::SwigPyIterator_medfile &":
        return _medfile.SwigPyIterator_medfile___isub__(self, n)

    def __add__(self, n: 'ptrdiff_t') -> "swig::SwigPyIterator_medfile *":
        return _medfile.SwigPyIterator_medfile___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _medfile.SwigPyIterator_medfile___sub__(self, *args)
    def __iter__(self): return self
    def __iter__(self):
        return self
SwigPyIterator_medfile_swigregister = _medfile.SwigPyIterator_medfile_swigregister
SwigPyIterator_medfile_swigregister(SwigPyIterator_medfile)

HAVE_CC_C99 = _medfile.HAVE_CC_C99
HAVE_FTIME = _medfile.HAVE_FTIME
HAVE_H5PUBLIC_H = _medfile.HAVE_H5PUBLIC_H
HAVE_INT64 = _medfile.HAVE_INT64
HAVE_INTTYPES_H = _medfile.HAVE_INTTYPES_H
HAVE_MALLOC_H = _medfile.HAVE_MALLOC_H
HAVE_MEMORY_H = _medfile.HAVE_MEMORY_H
HAVE_STDBOOL_H = _medfile.HAVE_STDBOOL_H
HAVE_STDINT_H = _medfile.HAVE_STDINT_H
HAVE_STDLIB_H = _medfile.HAVE_STDLIB_H
HAVE_STRING_H = _medfile.HAVE_STRING_H
HAVE_SYS_STAT_H = _medfile.HAVE_SYS_STAT_H
HAVE_SYS_TIMEB_H = _medfile.HAVE_SYS_TIMEB_H
HAVE_SYS_TYPES_H = _medfile.HAVE_SYS_TYPES_H
HAVE__BOOL = _medfile.HAVE__BOOL
MED_CHECK_23FORMAT = _medfile.MED_CHECK_23FORMAT
MED_HAVE_FORTRAN = _medfile.MED_HAVE_FORTRAN
MESGERR = _medfile.MESGERR
PACKAGE = _medfile.PACKAGE
PACKAGE_BUGREPORT = _medfile.PACKAGE_BUGREPORT
PACKAGE_NAME = _medfile.PACKAGE_NAME
PACKAGE_STRING = _medfile.PACKAGE_STRING
PACKAGE_URL = _medfile.PACKAGE_URL
PACKAGE_VERSION = _medfile.PACKAGE_VERSION
SIZEOF_FORTRAN_INTEGER = _medfile.SIZEOF_FORTRAN_INTEGER
SIZEOF_INT = _medfile.SIZEOF_INT
SIZEOF_LONG = _medfile.SIZEOF_LONG
STDC_HEADERS = _medfile.STDC_HEADERS
VERSION = _medfile.VERSION
HDF_VERSION_MAJOR_REF = _medfile.HDF_VERSION_MAJOR_REF
HDF_VERSION_MINOR_REF = _medfile.HDF_VERSION_MINOR_REF
HDF_VERSION_RELEASE_REF = _medfile.HDF_VERSION_RELEASE_REF
HDF_VERSION_NUM_REF = _medfile.HDF_VERSION_NUM_REF
H5F_LIBVER_18 = _medfile.H5F_LIBVER_18
MED_MAJOR_NUM = _medfile.MED_MAJOR_NUM
MED_MINOR_NUM = _medfile.MED_MINOR_NUM
MED_RELEASE_NUM = _medfile.MED_RELEASE_NUM
MED_NUM_MAJEUR = _medfile.MED_NUM_MAJEUR
MED_NUM_MINEUR = _medfile.MED_NUM_MINEUR
MED_NUM_RELEASE = _medfile.MED_NUM_RELEASE
MED_VERSION_STR = _medfile.MED_VERSION_STR
MED_MAX_PARA = _medfile.MED_MAX_PARA
MED_COMMENT_SIZE = _medfile.MED_COMMENT_SIZE
MED_IDENT_SIZE = _medfile.MED_IDENT_SIZE
MED_NAME_SIZE = _medfile.MED_NAME_SIZE
MED_SNAME_SIZE = _medfile.MED_SNAME_SIZE
MED_LNAME_SIZE = _medfile.MED_LNAME_SIZE
MED_SNAME_BLANK = _medfile.MED_SNAME_BLANK
MED_NAME_BLANK = _medfile.MED_NAME_BLANK
MED_PATHNAME_SIZE = _medfile.MED_PATHNAME_SIZE
MED_MAX_CHFID_PATH = _medfile.MED_MAX_CHFID_PATH
MED_FULL_INTERLACE = _medfile.MED_FULL_INTERLACE
MED_NO_INTERLACE = _medfile.MED_NO_INTERLACE
MED_UNDEF_INTERLACE = _medfile.MED_UNDEF_INTERLACE
MED_UNDEF_STMODE = _medfile.MED_UNDEF_STMODE
MED_GLOBAL_STMODE = _medfile.MED_GLOBAL_STMODE
MED_COMPACT_STMODE = _medfile.MED_COMPACT_STMODE
MED_GLOBAL_PFLMODE = _medfile.MED_GLOBAL_PFLMODE
MED_COMPACT_PFLMODE = _medfile.MED_COMPACT_PFLMODE
MED_UNDEF_PFLMODE = _medfile.MED_UNDEF_PFLMODE
MED_ACC_RDONLY = _medfile.MED_ACC_RDONLY
MED_ACC_RDWR = _medfile.MED_ACC_RDWR
MED_ACC_RDEXT = _medfile.MED_ACC_RDEXT
MED_ACC_CREAT = _medfile.MED_ACC_CREAT
MED_ACC_UNDEF = _medfile.MED_ACC_UNDEF
MED_UNSTRUCTURED_MESH = _medfile.MED_UNSTRUCTURED_MESH
MED_STRUCTURED_MESH = _medfile.MED_STRUCTURED_MESH
MED_UNDEF_MESH_TYPE = _medfile.MED_UNDEF_MESH_TYPE
MED_CARTESIAN_GRID = _medfile.MED_CARTESIAN_GRID
MED_POLAR_GRID = _medfile.MED_POLAR_GRID
MED_CURVILINEAR_GRID = _medfile.MED_CURVILINEAR_GRID
MED_UNDEF_GRID_TYPE = _medfile.MED_UNDEF_GRID_TYPE
MED_CELL = _medfile.MED_CELL
MED_DESCENDING_FACE = _medfile.MED_DESCENDING_FACE
MED_DESCENDING_EDGE = _medfile.MED_DESCENDING_EDGE
MED_NODE = _medfile.MED_NODE
MED_NODE_ELEMENT = _medfile.MED_NODE_ELEMENT
MED_STRUCT_ELEMENT = _medfile.MED_STRUCT_ELEMENT
MED_ALL_ENTITY_TYPE = _medfile.MED_ALL_ENTITY_TYPE
MED_UNDEF_ENTITY_TYPE = _medfile.MED_UNDEF_ENTITY_TYPE
MED_N_ENTITY_TYPES = _medfile.MED_N_ENTITY_TYPES
MED_COORDINATE = _medfile.MED_COORDINATE
MED_CONNECTIVITY = _medfile.MED_CONNECTIVITY
MED_NAME = _medfile.MED_NAME
MED_NUMBER = _medfile.MED_NUMBER
MED_FAMILY_NUMBER = _medfile.MED_FAMILY_NUMBER
MED_COORDINATE_AXIS1 = _medfile.MED_COORDINATE_AXIS1
MED_COORDINATE_AXIS2 = _medfile.MED_COORDINATE_AXIS2
MED_COORDINATE_AXIS3 = _medfile.MED_COORDINATE_AXIS3
MED_INDEX_FACE = _medfile.MED_INDEX_FACE
MED_INDEX_NODE = _medfile.MED_INDEX_NODE
MED_GLOBAL_NUMBER = _medfile.MED_GLOBAL_NUMBER
MED_VARIABLE_ATTRIBUTE = _medfile.MED_VARIABLE_ATTRIBUTE
MED_COORDINATE_TRSF = _medfile.MED_COORDINATE_TRSF
MED_UNDEF_DATATYPE = _medfile.MED_UNDEF_DATATYPE
MED_INTERNAL_FLOAT32 = _medfile.MED_INTERNAL_FLOAT32
MED_INTERNAL_FLOAT64 = _medfile.MED_INTERNAL_FLOAT64
MED_INTERNAL_INT32 = _medfile.MED_INTERNAL_INT32
MED_INTERNAL_INT64 = _medfile.MED_INTERNAL_INT64
MED_INTERNAL_INT = _medfile.MED_INTERNAL_INT
MED_INTERNAL_NAME = _medfile.MED_INTERNAL_NAME
MED_INTERNAL_SNAME = _medfile.MED_INTERNAL_SNAME
MED_INTERNAL_LNAME = _medfile.MED_INTERNAL_LNAME
MED_INTERNAL_IDENT = _medfile.MED_INTERNAL_IDENT
MED_INTERNAL_CHAR = _medfile.MED_INTERNAL_CHAR
MED_INTERNAL_UNDEF = _medfile.MED_INTERNAL_UNDEF
MED_DOUBLE = _medfile.MED_DOUBLE
MED_FLOAT64 = _medfile.MED_FLOAT64
MED_FLOAT32 = _medfile.MED_FLOAT32
MED_INT32 = _medfile.MED_INT32
MED_INT64 = _medfile.MED_INT64
MED_INT = _medfile.MED_INT
MED_ATT_FLOAT64 = _medfile.MED_ATT_FLOAT64
MED_ATT_INT = _medfile.MED_ATT_INT
MED_ATT_NAME = _medfile.MED_ATT_NAME
MED_ATT_UNDEF = _medfile.MED_ATT_UNDEF
MED_MESH = _medfile.MED_MESH
MED_FIELD = _medfile.MED_FIELD
MED_LIBRARY = _medfile.MED_LIBRARY
MED_FILE = _medfile.MED_FILE
MED_MESH_SUPPORT = _medfile.MED_MESH_SUPPORT
MED_ELSTRUCT = _medfile.MED_ELSTRUCT
MED_FAMILY = _medfile.MED_FAMILY
MED_EQUIVALENCE = _medfile.MED_EQUIVALENCE
MED_GROUP = _medfile.MED_GROUP
MED_JOINT = _medfile.MED_JOINT
MED_LOCALIZATION = _medfile.MED_LOCALIZATION
MED_PROFILE = _medfile.MED_PROFILE
MED_FILTER = _medfile.MED_FILTER
MED_INTERPOLATION = _medfile.MED_INTERPOLATION
MED_NUMERICAL_DATA = _medfile.MED_NUMERICAL_DATA
MED_LINK = _medfile.MED_LINK
MED_CLASS_UNDEF = _medfile.MED_CLASS_UNDEF
MED_CLASS_ALL = _medfile.MED_CLASS_ALL
MED_POINT1 = _medfile.MED_POINT1
MED_SEG2 = _medfile.MED_SEG2
MED_SEG3 = _medfile.MED_SEG3
MED_SEG4 = _medfile.MED_SEG4
MED_TRIA3 = _medfile.MED_TRIA3
MED_QUAD4 = _medfile.MED_QUAD4
MED_TRIA6 = _medfile.MED_TRIA6
MED_TRIA7 = _medfile.MED_TRIA7
MED_QUAD8 = _medfile.MED_QUAD8
MED_QUAD9 = _medfile.MED_QUAD9
MED_TETRA4 = _medfile.MED_TETRA4
MED_PYRA5 = _medfile.MED_PYRA5
MED_PENTA6 = _medfile.MED_PENTA6
MED_HEXA8 = _medfile.MED_HEXA8
MED_TETRA10 = _medfile.MED_TETRA10
MED_OCTA12 = _medfile.MED_OCTA12
MED_PYRA13 = _medfile.MED_PYRA13
MED_PENTA15 = _medfile.MED_PENTA15
MED_PENTA18 = _medfile.MED_PENTA18
MED_HEXA20 = _medfile.MED_HEXA20
MED_HEXA27 = _medfile.MED_HEXA27
MED_POLYGON = _medfile.MED_POLYGON
MED_POLYGON2 = _medfile.MED_POLYGON2
MED_POLYHEDRON = _medfile.MED_POLYHEDRON
MED_STRUCT_GEO_INTERNAL = _medfile.MED_STRUCT_GEO_INTERNAL
MED_STRUCT_GEO_SUP_INTERNAL = _medfile.MED_STRUCT_GEO_SUP_INTERNAL
MED_NONE = _medfile.MED_NONE
MED_NO_GEOTYPE = _medfile.MED_NO_GEOTYPE
MED_UNDEF_GEOTYPE = _medfile.MED_UNDEF_GEOTYPE
MED_UNDEF_GEOMETRY_TYPE = _medfile.MED_UNDEF_GEOMETRY_TYPE
MED_ALL_GEOTYPE = _medfile.MED_ALL_GEOTYPE
MED_GEO_ALL = _medfile.MED_GEO_ALL
MED_N_CELL_GEO = _medfile.MED_N_CELL_GEO
MED_N_CELL_FIXED_GEO = _medfile.MED_N_CELL_FIXED_GEO
MED_N_CELL_GEO_FIXED_CON = _medfile.MED_N_CELL_GEO_FIXED_CON
MED_N_FACE_GEO = _medfile.MED_N_FACE_GEO
MED_N_FACE_FIXED_GEO = _medfile.MED_N_FACE_FIXED_GEO
MED_N_FACE_GEO_FIXED_CON = _medfile.MED_N_FACE_GEO_FIXED_CON
MED_N_EDGE_TYPES = _medfile.MED_N_EDGE_TYPES
MED_N_EDGE_FIXED_GEO = _medfile.MED_N_EDGE_FIXED_GEO
MED_N_EDGE_GEO_FIXED_CON = _medfile.MED_N_EDGE_GEO_FIXED_CON
MED_N_NODE_GEO = _medfile.MED_N_NODE_GEO
MED_N_NODE_FIXED_GEO = _medfile.MED_N_NODE_FIXED_GEO
MED_N_NODE_GEO_FIXED_CON = _medfile.MED_N_NODE_GEO_FIXED_CON
MED_NODAL = _medfile.MED_NODAL
MED_DESCENDING = _medfile.MED_DESCENDING
MED_UNDEF_CONNECTIVITY_MODE = _medfile.MED_UNDEF_CONNECTIVITY_MODE
MED_NO_CMODE = _medfile.MED_NO_CMODE
MED_CARTESIAN = _medfile.MED_CARTESIAN
MED_CYLINDRICAL = _medfile.MED_CYLINDRICAL
MED_SPHERICAL = _medfile.MED_SPHERICAL
MED_UNDEF_AXIS_TYPE = _medfile.MED_UNDEF_AXIS_TYPE
MED_FALSE = _medfile.MED_FALSE
MED_TRUE = _medfile.MED_TRUE
MED_GAUSS_ELNO = _medfile.MED_GAUSS_ELNO
MED_IPOINT_ELNO = _medfile.MED_IPOINT_ELNO
MED_NO_NAME = _medfile.MED_NO_NAME
MED_NO_MESHNAME = _medfile.MED_NO_MESHNAME
MED_NO_MESH = _medfile.MED_NO_MESH
MED_NO_MESH_SUPPORT = _medfile.MED_NO_MESH_SUPPORT
MED_NO_LOCALIZATION = _medfile.MED_NO_LOCALIZATION
MED_NO_INTERPOLATION = _medfile.MED_NO_INTERPOLATION
MED_NO_IPOINT_INTERNAL = _medfile.MED_NO_IPOINT_INTERNAL
MED_NO_PROFILE = _medfile.MED_NO_PROFILE
MED_NO_GROUP = _medfile.MED_NO_GROUP
MED_ALLENTITIES_PROFILE = _medfile.MED_ALLENTITIES_PROFILE
MED_NO_PROFILE_INTERNAL = _medfile.MED_NO_PROFILE_INTERNAL
MED_SAME_PROFILE_INTERNAL = _medfile.MED_SAME_PROFILE_INTERNAL
MED_ALL_CONSTITUENT = _medfile.MED_ALL_CONSTITUENT
MED_UNDEF_SIZE = _medfile.MED_UNDEF_SIZE
MED_NO_PROFILE_SIZE = _medfile.MED_NO_PROFILE_SIZE
MED_SORT_DTIT = _medfile.MED_SORT_DTIT
MED_SORT_ITDT = _medfile.MED_SORT_ITDT
MED_SORT_UNDEF = _medfile.MED_SORT_UNDEF
MED_NO_DT = _medfile.MED_NO_DT
MED_NO_IT = _medfile.MED_NO_IT
MED_UNDEF_DT = _medfile.MED_UNDEF_DT
MED_ATT_NOT_FILLED = _medfile.MED_ATT_NOT_FILLED
MED_MAX_FILTER_SPACES = _medfile.MED_MAX_FILTER_SPACES
class med_filter(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, med_filter, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, med_filter, name)
    __repr__ = _swig_repr
    __swig_setmethods__["nspaces"] = _medfile.med_filter_nspaces_set
    __swig_getmethods__["nspaces"] = _medfile.med_filter_nspaces_get
    if _newclass:
        nspaces = _swig_property(_medfile.med_filter_nspaces_get, _medfile.med_filter_nspaces_set)
    __swig_setmethods__["memspace"] = _medfile.med_filter_memspace_set
    __swig_getmethods__["memspace"] = _medfile.med_filter_memspace_get
    if _newclass:
        memspace = _swig_property(_medfile.med_filter_memspace_get, _medfile.med_filter_memspace_set)
    __swig_setmethods__["diskspace"] = _medfile.med_filter_diskspace_set
    __swig_getmethods__["diskspace"] = _medfile.med_filter_diskspace_get
    if _newclass:
        diskspace = _swig_property(_medfile.med_filter_diskspace_get, _medfile.med_filter_diskspace_set)
    __swig_setmethods__["nentity"] = _medfile.med_filter_nentity_set
    __swig_getmethods__["nentity"] = _medfile.med_filter_nentity_get
    if _newclass:
        nentity = _swig_property(_medfile.med_filter_nentity_get, _medfile.med_filter_nentity_set)
    __swig_setmethods__["nvaluesperentity"] = _medfile.med_filter_nvaluesperentity_set
    __swig_getmethods__["nvaluesperentity"] = _medfile.med_filter_nvaluesperentity_get
    if _newclass:
        nvaluesperentity = _swig_property(_medfile.med_filter_nvaluesperentity_get, _medfile.med_filter_nvaluesperentity_set)
    __swig_setmethods__["nconstituentpervalue"] = _medfile.med_filter_nconstituentpervalue_set
    __swig_getmethods__["nconstituentpervalue"] = _medfile.med_filter_nconstituentpervalue_get
    if _newclass:
        nconstituentpervalue = _swig_property(_medfile.med_filter_nconstituentpervalue_get, _medfile.med_filter_nconstituentpervalue_set)
    __swig_setmethods__["constituentselect"] = _medfile.med_filter_constituentselect_set
    __swig_getmethods__["constituentselect"] = _medfile.med_filter_constituentselect_get
    if _newclass:
        constituentselect = _swig_property(_medfile.med_filter_constituentselect_get, _medfile.med_filter_constituentselect_set)
    __swig_setmethods__["switchmode"] = _medfile.med_filter_switchmode_set
    __swig_getmethods__["switchmode"] = _medfile.med_filter_switchmode_get
    if _newclass:
        switchmode = _swig_property(_medfile.med_filter_switchmode_get, _medfile.med_filter_switchmode_set)
    __swig_setmethods__["filterarraysize"] = _medfile.med_filter_filterarraysize_set
    __swig_getmethods__["filterarraysize"] = _medfile.med_filter_filterarraysize_get
    if _newclass:
        filterarraysize = _swig_property(_medfile.med_filter_filterarraysize_get, _medfile.med_filter_filterarraysize_set)
    __swig_setmethods__["filterarray23v30"] = _medfile.med_filter_filterarray23v30_set
    __swig_getmethods__["filterarray23v30"] = _medfile.med_filter_filterarray23v30_get
    if _newclass:
        filterarray23v30 = _swig_property(_medfile.med_filter_filterarray23v30_get, _medfile.med_filter_filterarray23v30_set)
    __swig_setmethods__["profilearraysize"] = _medfile.med_filter_profilearraysize_set
    __swig_getmethods__["profilearraysize"] = _medfile.med_filter_profilearraysize_get
    if _newclass:
        profilearraysize = _swig_property(_medfile.med_filter_profilearraysize_get, _medfile.med_filter_profilearraysize_set)
    __swig_setmethods__["storagemode"] = _medfile.med_filter_storagemode_set
    __swig_getmethods__["storagemode"] = _medfile.med_filter_storagemode_get
    if _newclass:
        storagemode = _swig_property(_medfile.med_filter_storagemode_get, _medfile.med_filter_storagemode_set)
    __swig_setmethods__["profilename"] = _medfile.med_filter_profilename_set
    __swig_getmethods__["profilename"] = _medfile.med_filter_profilename_get
    if _newclass:
        profilename = _swig_property(_medfile.med_filter_profilename_get, _medfile.med_filter_profilename_set)

    def __init__(self):
        """__init__(self) -> med_filter"""
        this = _medfile.new_med_filter()
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this
    __swig_destroy__ = _medfile.delete_med_filter
    __del__ = lambda self: None
med_filter_swigregister = _medfile.med_filter_swigregister
med_filter_swigregister(med_filter)

MED_NO_FILTER_SIZE = _medfile.MED_NO_FILTER_SIZE
MED_NO_PROFILE_F = _medfile.MED_NO_PROFILE_F
class med_file_version(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, med_file_version, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, med_file_version, name)
    __repr__ = _swig_repr
    __swig_setmethods__["majeur"] = _medfile.med_file_version_majeur_set
    __swig_getmethods__["majeur"] = _medfile.med_file_version_majeur_get
    if _newclass:
        majeur = _swig_property(_medfile.med_file_version_majeur_get, _medfile.med_file_version_majeur_set)
    __swig_setmethods__["mineur"] = _medfile.med_file_version_mineur_set
    __swig_getmethods__["mineur"] = _medfile.med_file_version_mineur_get
    if _newclass:
        mineur = _swig_property(_medfile.med_file_version_mineur_get, _medfile.med_file_version_mineur_set)
    __swig_setmethods__["release"] = _medfile.med_file_version_release_set
    __swig_getmethods__["release"] = _medfile.med_file_version_release_get
    if _newclass:
        release = _swig_property(_medfile.med_file_version_release_get, _medfile.med_file_version_release_set)

    def __init__(self):
        """__init__(self) -> med_file_version"""
        this = _medfile.new_med_file_version()
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this
    __swig_destroy__ = _medfile.delete_med_file_version
    __del__ = lambda self: None
med_file_version_swigregister = _medfile.med_file_version_swigregister
med_file_version_swigregister(med_file_version)

class med_memfile(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, med_memfile, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, med_memfile, name)
    __repr__ = _swig_repr
    __swig_setmethods__["app_image_ptr"] = _medfile.med_memfile_app_image_ptr_set
    __swig_getmethods__["app_image_ptr"] = _medfile.med_memfile_app_image_ptr_get
    if _newclass:
        app_image_ptr = _swig_property(_medfile.med_memfile_app_image_ptr_get, _medfile.med_memfile_app_image_ptr_set)
    __swig_setmethods__["app_image_size"] = _medfile.med_memfile_app_image_size_set
    __swig_getmethods__["app_image_size"] = _medfile.med_memfile_app_image_size_get
    if _newclass:
        app_image_size = _swig_property(_medfile.med_memfile_app_image_size_get, _medfile.med_memfile_app_image_size_set)
    __swig_setmethods__["ref_count"] = _medfile.med_memfile_ref_count_set
    __swig_getmethods__["ref_count"] = _medfile.med_memfile_ref_count_get
    if _newclass:
        ref_count = _swig_property(_medfile.med_memfile_ref_count_get, _medfile.med_memfile_ref_count_set)
    __swig_setmethods__["fapl_image_ptr"] = _medfile.med_memfile_fapl_image_ptr_set
    __swig_getmethods__["fapl_image_ptr"] = _medfile.med_memfile_fapl_image_ptr_get
    if _newclass:
        fapl_image_ptr = _swig_property(_medfile.med_memfile_fapl_image_ptr_get, _medfile.med_memfile_fapl_image_ptr_set)
    __swig_setmethods__["fapl_image_size"] = _medfile.med_memfile_fapl_image_size_set
    __swig_getmethods__["fapl_image_size"] = _medfile.med_memfile_fapl_image_size_get
    if _newclass:
        fapl_image_size = _swig_property(_medfile.med_memfile_fapl_image_size_get, _medfile.med_memfile_fapl_image_size_set)
    __swig_setmethods__["fapl_ref_count"] = _medfile.med_memfile_fapl_ref_count_set
    __swig_getmethods__["fapl_ref_count"] = _medfile.med_memfile_fapl_ref_count_get
    if _newclass:
        fapl_ref_count = _swig_property(_medfile.med_memfile_fapl_ref_count_get, _medfile.med_memfile_fapl_ref_count_set)
    __swig_setmethods__["vfd_image_ptr"] = _medfile.med_memfile_vfd_image_ptr_set
    __swig_getmethods__["vfd_image_ptr"] = _medfile.med_memfile_vfd_image_ptr_get
    if _newclass:
        vfd_image_ptr = _swig_property(_medfile.med_memfile_vfd_image_ptr_get, _medfile.med_memfile_vfd_image_ptr_set)
    __swig_setmethods__["vfd_image_size"] = _medfile.med_memfile_vfd_image_size_set
    __swig_getmethods__["vfd_image_size"] = _medfile.med_memfile_vfd_image_size_get
    if _newclass:
        vfd_image_size = _swig_property(_medfile.med_memfile_vfd_image_size_get, _medfile.med_memfile_vfd_image_size_set)
    __swig_setmethods__["vfd_ref_count"] = _medfile.med_memfile_vfd_ref_count_set
    __swig_getmethods__["vfd_ref_count"] = _medfile.med_memfile_vfd_ref_count_get
    if _newclass:
        vfd_ref_count = _swig_property(_medfile.med_memfile_vfd_ref_count_get, _medfile.med_memfile_vfd_ref_count_set)
    __swig_setmethods__["flags"] = _medfile.med_memfile_flags_set
    __swig_getmethods__["flags"] = _medfile.med_memfile_flags_get
    if _newclass:
        flags = _swig_property(_medfile.med_memfile_flags_get, _medfile.med_memfile_flags_set)

    def __init__(self):
        """__init__(self) -> med_memfile"""
        this = _medfile.new_med_memfile()
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this
    __swig_destroy__ = _medfile.delete_med_memfile
    __del__ = lambda self: None
med_memfile_swigregister = _medfile.med_memfile_swigregister
med_memfile_swigregister(med_memfile)

MED_PARTICLE_NAME = _medfile.MED_PARTICLE_NAME
MED_BALL_NAME = _medfile.MED_BALL_NAME
MED_BEAM_NAME = _medfile.MED_BEAM_NAME
MED_PARTICLE_LABEL = _medfile.MED_PARTICLE_LABEL
MED_BALL_DIAMETER = _medfile.MED_BALL_DIAMETER
MED_BEAM_THICKNESS = _medfile.MED_BEAM_THICKNESS
import med.medenum
class MEDBOOL(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, MEDBOOL, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, MEDBOOL, name)
    __repr__ = _swig_repr

    def iterator(self) -> "swig::SwigPyIterator_medfile *":
        return _medfile.MEDBOOL_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self) -> "bool":
        return _medfile.MEDBOOL___nonzero__(self)

    def __bool__(self) -> "bool":
        return _medfile.MEDBOOL___bool__(self)

    def __len__(self) -> "std::vector< bool >::size_type":
        return _medfile.MEDBOOL___len__(self)

    def __getslice__(self, i: 'std::vector< bool >::difference_type', j: 'std::vector< bool >::difference_type') -> "std::vector< bool,std::allocator< bool > > *":
        return _medfile.MEDBOOL___getslice__(self, i, j)

    def __setslice__(self, *args) -> "void":
        return _medfile.MEDBOOL___setslice__(self, *args)

    def __delslice__(self, i: 'std::vector< bool >::difference_type', j: 'std::vector< bool >::difference_type') -> "void":
        return _medfile.MEDBOOL___delslice__(self, i, j)

    def __delitem__(self, *args) -> "void":
        return _medfile.MEDBOOL___delitem__(self, *args)

    def __getitem__(self, *args) -> "std::vector< bool >::value_type":
        return _medfile.MEDBOOL___getitem__(self, *args)

    def __setitem__(self, *args) -> "void":
        return _medfile.MEDBOOL___setitem__(self, *args)

    def pop(self) -> "std::vector< bool >::value_type":
        return _medfile.MEDBOOL_pop(self)

    def append(self, x: 'std::vector< bool >::value_type') -> "void":
        return _medfile.MEDBOOL_append(self, x)

    def empty(self) -> "bool":
        return _medfile.MEDBOOL_empty(self)

    def size(self) -> "std::vector< bool >::size_type":
        return _medfile.MEDBOOL_size(self)

    def swap(self, v: 'MEDBOOL') -> "void":
        return _medfile.MEDBOOL_swap(self, v)

    def begin(self) -> "std::vector< bool >::iterator":
        return _medfile.MEDBOOL_begin(self)

    def end(self) -> "std::vector< bool >::iterator":
        return _medfile.MEDBOOL_end(self)

    def rbegin(self) -> "std::vector< bool >::reverse_iterator":
        return _medfile.MEDBOOL_rbegin(self)

    def rend(self) -> "std::vector< bool >::reverse_iterator":
        return _medfile.MEDBOOL_rend(self)

    def clear(self) -> "void":
        return _medfile.MEDBOOL_clear(self)

    def get_allocator(self) -> "std::vector< bool >::allocator_type":
        return _medfile.MEDBOOL_get_allocator(self)

    def pop_back(self) -> "void":
        return _medfile.MEDBOOL_pop_back(self)

    def erase(self, *args) -> "std::vector< bool >::iterator":
        return _medfile.MEDBOOL_erase(self, *args)

    def __init__(self, *args):
        this = _medfile.new_MEDBOOL(*args)
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this

    def push_back(self, x: 'std::vector< bool >::value_type') -> "void":
        return _medfile.MEDBOOL_push_back(self, x)

    def front(self) -> "std::vector< bool >::value_type":
        return _medfile.MEDBOOL_front(self)

    def back(self) -> "std::vector< bool >::value_type":
        return _medfile.MEDBOOL_back(self)

    def assign(self, n: 'std::vector< bool >::size_type', x: 'std::vector< bool >::value_type') -> "void":
        return _medfile.MEDBOOL_assign(self, n, x)

    def resize(self, *args) -> "void":
        return _medfile.MEDBOOL_resize(self, *args)

    def insert(self, *args) -> "void":
        return _medfile.MEDBOOL_insert(self, *args)

    def reserve(self, n: 'std::vector< bool >::size_type') -> "void":
        return _medfile.MEDBOOL_reserve(self, n)

    def capacity(self) -> "std::vector< bool >::size_type":
        return _medfile.MEDBOOL_capacity(self)
    __swig_destroy__ = _medfile.delete_MEDBOOL
    __del__ = lambda self: None
MEDBOOL_swigregister = _medfile.MEDBOOL_swigregister
MEDBOOL_swigregister(MEDBOOL)
cvar = _medfile.cvar
MED_GET_ENTITY_TYPENAME = cvar.MED_GET_ENTITY_TYPENAME
MED_GET_CELL_GEOMETRY_TYPENAME = cvar.MED_GET_CELL_GEOMETRY_TYPENAME
MED_GET_FACE_GEOMETRY_TYPENAME = cvar.MED_GET_FACE_GEOMETRY_TYPENAME


MEDBOOL.__str__= lambda self: str([x for x in self])
MEDBOOL.__repr__= lambda self: "MEDBOOL("+str([x for x in self])+")"

class MEDFLOAT(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, MEDFLOAT, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, MEDFLOAT, name)
    __repr__ = _swig_repr

    def iterator(self) -> "swig::SwigPyIterator_medfile *":
        return _medfile.MEDFLOAT_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self) -> "bool":
        return _medfile.MEDFLOAT___nonzero__(self)

    def __bool__(self) -> "bool":
        return _medfile.MEDFLOAT___bool__(self)

    def __len__(self) -> "std::vector< double >::size_type":
        return _medfile.MEDFLOAT___len__(self)

    def __getslice__(self, i: 'std::vector< double >::difference_type', j: 'std::vector< double >::difference_type') -> "std::vector< double,std::allocator< double > > *":
        return _medfile.MEDFLOAT___getslice__(self, i, j)

    def __setslice__(self, *args) -> "void":
        return _medfile.MEDFLOAT___setslice__(self, *args)

    def __delslice__(self, i: 'std::vector< double >::difference_type', j: 'std::vector< double >::difference_type') -> "void":
        return _medfile.MEDFLOAT___delslice__(self, i, j)

    def __delitem__(self, *args) -> "void":
        return _medfile.MEDFLOAT___delitem__(self, *args)

    def __getitem__(self, *args) -> "std::vector< double >::value_type const &":
        return _medfile.MEDFLOAT___getitem__(self, *args)

    def __setitem__(self, *args) -> "void":
        return _medfile.MEDFLOAT___setitem__(self, *args)

    def pop(self) -> "std::vector< double >::value_type":
        return _medfile.MEDFLOAT_pop(self)

    def append(self, x: 'std::vector< double >::value_type const &') -> "void":
        return _medfile.MEDFLOAT_append(self, x)

    def empty(self) -> "bool":
        return _medfile.MEDFLOAT_empty(self)

    def size(self) -> "std::vector< double >::size_type":
        return _medfile.MEDFLOAT_size(self)

    def swap(self, v: 'MEDFLOAT') -> "void":
        return _medfile.MEDFLOAT_swap(self, v)

    def begin(self) -> "std::vector< double >::iterator":
        return _medfile.MEDFLOAT_begin(self)

    def end(self) -> "std::vector< double >::iterator":
        return _medfile.MEDFLOAT_end(self)

    def rbegin(self) -> "std::vector< double >::reverse_iterator":
        return _medfile.MEDFLOAT_rbegin(self)

    def rend(self) -> "std::vector< double >::reverse_iterator":
        return _medfile.MEDFLOAT_rend(self)

    def clear(self) -> "void":
        return _medfile.MEDFLOAT_clear(self)

    def get_allocator(self) -> "std::vector< double >::allocator_type":
        return _medfile.MEDFLOAT_get_allocator(self)

    def pop_back(self) -> "void":
        return _medfile.MEDFLOAT_pop_back(self)

    def erase(self, *args) -> "std::vector< double >::iterator":
        return _medfile.MEDFLOAT_erase(self, *args)

    def __init__(self, *args):
        this = _medfile.new_MEDFLOAT(*args)
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this

    def push_back(self, x: 'std::vector< double >::value_type const &') -> "void":
        return _medfile.MEDFLOAT_push_back(self, x)

    def front(self) -> "std::vector< double >::value_type const &":
        return _medfile.MEDFLOAT_front(self)

    def back(self) -> "std::vector< double >::value_type const &":
        return _medfile.MEDFLOAT_back(self)

    def assign(self, n: 'std::vector< double >::size_type', x: 'std::vector< double >::value_type const &') -> "void":
        return _medfile.MEDFLOAT_assign(self, n, x)

    def resize(self, *args) -> "void":
        return _medfile.MEDFLOAT_resize(self, *args)

    def insert(self, *args) -> "void":
        return _medfile.MEDFLOAT_insert(self, *args)

    def reserve(self, n: 'std::vector< double >::size_type') -> "void":
        return _medfile.MEDFLOAT_reserve(self, n)

    def capacity(self) -> "std::vector< double >::size_type":
        return _medfile.MEDFLOAT_capacity(self)

    def __iadd__(self, value: 'MEDFLOAT') -> "std::vector< med_float,std::allocator< med_float > > &":
        return _medfile.MEDFLOAT___iadd__(self, value)

    def __add__(self, value: 'MEDFLOAT') -> "std::vector< med_float,std::allocator< med_float > >":
        return _medfile.MEDFLOAT___add__(self, value)

    def __isub__(self, value: 'MEDFLOAT') -> "std::vector< med_float,std::allocator< med_float > > &":
        return _medfile.MEDFLOAT___isub__(self, value)

    def __sub__(self, value: 'MEDFLOAT') -> "std::vector< med_float,std::allocator< med_float > >":
        return _medfile.MEDFLOAT___sub__(self, value)

    def __imul__(self, value: 'MEDFLOAT') -> "std::vector< med_float,std::allocator< med_float > > &":
        return _medfile.MEDFLOAT___imul__(self, value)

    def __mul__(self, value: 'MEDFLOAT') -> "std::vector< med_float,std::allocator< med_float > >":
        return _medfile.MEDFLOAT___mul__(self, value)

    def __itruediv__(self, *args):
        return _medfile.MEDFLOAT___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medfile.MEDFLOAT___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value: 'MEDFLOAT') -> "bool":
        return _medfile.MEDFLOAT___le__(self, value)

    def __lt__(self, value: 'MEDFLOAT') -> "bool":
        return _medfile.MEDFLOAT___lt__(self, value)

    def __gt__(self, value: 'MEDFLOAT') -> "bool":
        return _medfile.MEDFLOAT___gt__(self, value)

    def __ge__(self, value: 'MEDFLOAT') -> "bool":
        return _medfile.MEDFLOAT___ge__(self, value)

    def __eq__(self, value: 'MEDFLOAT') -> "bool":
        return _medfile.MEDFLOAT___eq__(self, value)

    def __ne__(self, value: 'MEDFLOAT') -> "bool":
        return _medfile.MEDFLOAT___ne__(self, value)
    __swig_destroy__ = _medfile.delete_MEDFLOAT
    __del__ = lambda self: None
MEDFLOAT_swigregister = _medfile.MEDFLOAT_swigregister
MEDFLOAT_swigregister(MEDFLOAT)


MEDFLOAT.__str__= lambda self: str([x for x in self])
MEDFLOAT.__repr__= lambda self:"MEDFLOAT" +"("+str([x for x in self])+")"


MEDFLOAT64=MEDFLOAT
MEDDOUBLE=MEDFLOAT

class MEDFLOAT32(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, MEDFLOAT32, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, MEDFLOAT32, name)
    __repr__ = _swig_repr

    def iterator(self) -> "swig::SwigPyIterator_medfile *":
        return _medfile.MEDFLOAT32_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self) -> "bool":
        return _medfile.MEDFLOAT32___nonzero__(self)

    def __bool__(self) -> "bool":
        return _medfile.MEDFLOAT32___bool__(self)

    def __len__(self) -> "std::vector< float >::size_type":
        return _medfile.MEDFLOAT32___len__(self)

    def __getslice__(self, i: 'std::vector< float >::difference_type', j: 'std::vector< float >::difference_type') -> "std::vector< float,std::allocator< float > > *":
        return _medfile.MEDFLOAT32___getslice__(self, i, j)

    def __setslice__(self, *args) -> "void":
        return _medfile.MEDFLOAT32___setslice__(self, *args)

    def __delslice__(self, i: 'std::vector< float >::difference_type', j: 'std::vector< float >::difference_type') -> "void":
        return _medfile.MEDFLOAT32___delslice__(self, i, j)

    def __delitem__(self, *args) -> "void":
        return _medfile.MEDFLOAT32___delitem__(self, *args)

    def __getitem__(self, *args) -> "std::vector< float >::value_type const &":
        return _medfile.MEDFLOAT32___getitem__(self, *args)

    def __setitem__(self, *args) -> "void":
        return _medfile.MEDFLOAT32___setitem__(self, *args)

    def pop(self) -> "std::vector< float >::value_type":
        return _medfile.MEDFLOAT32_pop(self)

    def append(self, x: 'std::vector< float >::value_type const &') -> "void":
        return _medfile.MEDFLOAT32_append(self, x)

    def empty(self) -> "bool":
        return _medfile.MEDFLOAT32_empty(self)

    def size(self) -> "std::vector< float >::size_type":
        return _medfile.MEDFLOAT32_size(self)

    def swap(self, v: 'MEDFLOAT32') -> "void":
        return _medfile.MEDFLOAT32_swap(self, v)

    def begin(self) -> "std::vector< float >::iterator":
        return _medfile.MEDFLOAT32_begin(self)

    def end(self) -> "std::vector< float >::iterator":
        return _medfile.MEDFLOAT32_end(self)

    def rbegin(self) -> "std::vector< float >::reverse_iterator":
        return _medfile.MEDFLOAT32_rbegin(self)

    def rend(self) -> "std::vector< float >::reverse_iterator":
        return _medfile.MEDFLOAT32_rend(self)

    def clear(self) -> "void":
        return _medfile.MEDFLOAT32_clear(self)

    def get_allocator(self) -> "std::vector< float >::allocator_type":
        return _medfile.MEDFLOAT32_get_allocator(self)

    def pop_back(self) -> "void":
        return _medfile.MEDFLOAT32_pop_back(self)

    def erase(self, *args) -> "std::vector< float >::iterator":
        return _medfile.MEDFLOAT32_erase(self, *args)

    def __init__(self, *args):
        this = _medfile.new_MEDFLOAT32(*args)
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this

    def push_back(self, x: 'std::vector< float >::value_type const &') -> "void":
        return _medfile.MEDFLOAT32_push_back(self, x)

    def front(self) -> "std::vector< float >::value_type const &":
        return _medfile.MEDFLOAT32_front(self)

    def back(self) -> "std::vector< float >::value_type const &":
        return _medfile.MEDFLOAT32_back(self)

    def assign(self, n: 'std::vector< float >::size_type', x: 'std::vector< float >::value_type const &') -> "void":
        return _medfile.MEDFLOAT32_assign(self, n, x)

    def resize(self, *args) -> "void":
        return _medfile.MEDFLOAT32_resize(self, *args)

    def insert(self, *args) -> "void":
        return _medfile.MEDFLOAT32_insert(self, *args)

    def reserve(self, n: 'std::vector< float >::size_type') -> "void":
        return _medfile.MEDFLOAT32_reserve(self, n)

    def capacity(self) -> "std::vector< float >::size_type":
        return _medfile.MEDFLOAT32_capacity(self)

    def __iadd__(self, value: 'MEDFLOAT32') -> "std::vector< med_float32,std::allocator< med_float32 > > &":
        return _medfile.MEDFLOAT32___iadd__(self, value)

    def __add__(self, value: 'MEDFLOAT32') -> "std::vector< med_float32,std::allocator< med_float32 > >":
        return _medfile.MEDFLOAT32___add__(self, value)

    def __isub__(self, value: 'MEDFLOAT32') -> "std::vector< med_float32,std::allocator< med_float32 > > &":
        return _medfile.MEDFLOAT32___isub__(self, value)

    def __sub__(self, value: 'MEDFLOAT32') -> "std::vector< med_float32,std::allocator< med_float32 > >":
        return _medfile.MEDFLOAT32___sub__(self, value)

    def __imul__(self, value: 'MEDFLOAT32') -> "std::vector< med_float32,std::allocator< med_float32 > > &":
        return _medfile.MEDFLOAT32___imul__(self, value)

    def __mul__(self, value: 'MEDFLOAT32') -> "std::vector< med_float32,std::allocator< med_float32 > >":
        return _medfile.MEDFLOAT32___mul__(self, value)

    def __itruediv__(self, *args):
        return _medfile.MEDFLOAT32___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medfile.MEDFLOAT32___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value: 'MEDFLOAT32') -> "bool":
        return _medfile.MEDFLOAT32___le__(self, value)

    def __lt__(self, value: 'MEDFLOAT32') -> "bool":
        return _medfile.MEDFLOAT32___lt__(self, value)

    def __gt__(self, value: 'MEDFLOAT32') -> "bool":
        return _medfile.MEDFLOAT32___gt__(self, value)

    def __ge__(self, value: 'MEDFLOAT32') -> "bool":
        return _medfile.MEDFLOAT32___ge__(self, value)

    def __eq__(self, value: 'MEDFLOAT32') -> "bool":
        return _medfile.MEDFLOAT32___eq__(self, value)

    def __ne__(self, value: 'MEDFLOAT32') -> "bool":
        return _medfile.MEDFLOAT32___ne__(self, value)
    __swig_destroy__ = _medfile.delete_MEDFLOAT32
    __del__ = lambda self: None
MEDFLOAT32_swigregister = _medfile.MEDFLOAT32_swigregister
MEDFLOAT32_swigregister(MEDFLOAT32)


MEDFLOAT32.__str__= lambda self: str([x for x in self])
MEDFLOAT32.__repr__= lambda self:"MEDFLOAT32" +"("+str([x for x in self])+")"

class MEDINT(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, MEDINT, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, MEDINT, name)
    __repr__ = _swig_repr

    def iterator(self) -> "swig::SwigPyIterator_medfile *":
        return _medfile.MEDINT_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self) -> "bool":
        return _medfile.MEDINT___nonzero__(self)

    def __bool__(self) -> "bool":
        return _medfile.MEDINT___bool__(self)

    def __len__(self) -> "std::vector< int >::size_type":
        return _medfile.MEDINT___len__(self)

    def __getslice__(self, i: 'std::vector< int >::difference_type', j: 'std::vector< int >::difference_type') -> "std::vector< int,std::allocator< int > > *":
        return _medfile.MEDINT___getslice__(self, i, j)

    def __setslice__(self, *args) -> "void":
        return _medfile.MEDINT___setslice__(self, *args)

    def __delslice__(self, i: 'std::vector< int >::difference_type', j: 'std::vector< int >::difference_type') -> "void":
        return _medfile.MEDINT___delslice__(self, i, j)

    def __delitem__(self, *args) -> "void":
        return _medfile.MEDINT___delitem__(self, *args)

    def __getitem__(self, *args) -> "std::vector< int >::value_type const &":
        return _medfile.MEDINT___getitem__(self, *args)

    def __setitem__(self, *args) -> "void":
        return _medfile.MEDINT___setitem__(self, *args)

    def pop(self) -> "std::vector< int >::value_type":
        return _medfile.MEDINT_pop(self)

    def append(self, x: 'std::vector< int >::value_type const &') -> "void":
        return _medfile.MEDINT_append(self, x)

    def empty(self) -> "bool":
        return _medfile.MEDINT_empty(self)

    def size(self) -> "std::vector< int >::size_type":
        return _medfile.MEDINT_size(self)

    def swap(self, v: 'MEDINT') -> "void":
        return _medfile.MEDINT_swap(self, v)

    def begin(self) -> "std::vector< int >::iterator":
        return _medfile.MEDINT_begin(self)

    def end(self) -> "std::vector< int >::iterator":
        return _medfile.MEDINT_end(self)

    def rbegin(self) -> "std::vector< int >::reverse_iterator":
        return _medfile.MEDINT_rbegin(self)

    def rend(self) -> "std::vector< int >::reverse_iterator":
        return _medfile.MEDINT_rend(self)

    def clear(self) -> "void":
        return _medfile.MEDINT_clear(self)

    def get_allocator(self) -> "std::vector< int >::allocator_type":
        return _medfile.MEDINT_get_allocator(self)

    def pop_back(self) -> "void":
        return _medfile.MEDINT_pop_back(self)

    def erase(self, *args) -> "std::vector< int >::iterator":
        return _medfile.MEDINT_erase(self, *args)

    def __init__(self, *args):
        this = _medfile.new_MEDINT(*args)
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this

    def push_back(self, x: 'std::vector< int >::value_type const &') -> "void":
        return _medfile.MEDINT_push_back(self, x)

    def front(self) -> "std::vector< int >::value_type const &":
        return _medfile.MEDINT_front(self)

    def back(self) -> "std::vector< int >::value_type const &":
        return _medfile.MEDINT_back(self)

    def assign(self, n: 'std::vector< int >::size_type', x: 'std::vector< int >::value_type const &') -> "void":
        return _medfile.MEDINT_assign(self, n, x)

    def resize(self, *args) -> "void":
        return _medfile.MEDINT_resize(self, *args)

    def insert(self, *args) -> "void":
        return _medfile.MEDINT_insert(self, *args)

    def reserve(self, n: 'std::vector< int >::size_type') -> "void":
        return _medfile.MEDINT_reserve(self, n)

    def capacity(self) -> "std::vector< int >::size_type":
        return _medfile.MEDINT_capacity(self)

    def __iadd__(self, value: 'MEDINT') -> "std::vector< med_int,std::allocator< med_int > > &":
        return _medfile.MEDINT___iadd__(self, value)

    def __add__(self, value: 'MEDINT') -> "std::vector< med_int,std::allocator< med_int > >":
        return _medfile.MEDINT___add__(self, value)

    def __isub__(self, value: 'MEDINT') -> "std::vector< med_int,std::allocator< med_int > > &":
        return _medfile.MEDINT___isub__(self, value)

    def __sub__(self, value: 'MEDINT') -> "std::vector< med_int,std::allocator< med_int > >":
        return _medfile.MEDINT___sub__(self, value)

    def __imul__(self, value: 'MEDINT') -> "std::vector< med_int,std::allocator< med_int > > &":
        return _medfile.MEDINT___imul__(self, value)

    def __mul__(self, value: 'MEDINT') -> "std::vector< med_int,std::allocator< med_int > >":
        return _medfile.MEDINT___mul__(self, value)

    def __itruediv__(self, *args):
        return _medfile.MEDINT___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medfile.MEDINT___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value: 'MEDINT') -> "bool":
        return _medfile.MEDINT___le__(self, value)

    def __lt__(self, value: 'MEDINT') -> "bool":
        return _medfile.MEDINT___lt__(self, value)

    def __gt__(self, value: 'MEDINT') -> "bool":
        return _medfile.MEDINT___gt__(self, value)

    def __ge__(self, value: 'MEDINT') -> "bool":
        return _medfile.MEDINT___ge__(self, value)

    def __eq__(self, value: 'MEDINT') -> "bool":
        return _medfile.MEDINT___eq__(self, value)

    def __ne__(self, value: 'MEDINT') -> "bool":
        return _medfile.MEDINT___ne__(self, value)
    __swig_destroy__ = _medfile.delete_MEDINT
    __del__ = lambda self: None
MEDINT_swigregister = _medfile.MEDINT_swigregister
MEDINT_swigregister(MEDINT)


MEDINT.__str__= lambda self: str([x for x in self])
MEDINT.__repr__= lambda self:"MEDINT" +"("+str([x for x in self])+")"


MEDINT32=MEDINT


MEDINT64=None

class MEDCHAR(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, MEDCHAR, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, MEDCHAR, name)
    __repr__ = _swig_repr

    def iterator(self) -> "swig::SwigPyIterator_medfile *":
        return _medfile.MEDCHAR_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self) -> "bool":
        return _medfile.MEDCHAR___nonzero__(self)

    def __bool__(self) -> "bool":
        return _medfile.MEDCHAR___bool__(self)

    def __len__(self) -> "std::vector< char >::size_type":
        return _medfile.MEDCHAR___len__(self)

    def __getslice__(self, i: 'std::vector< char >::difference_type', j: 'std::vector< char >::difference_type') -> "std::vector< char,std::allocator< char > > *":
        return _medfile.MEDCHAR___getslice__(self, i, j)

    def __setslice__(self, *args) -> "void":
        return _medfile.MEDCHAR___setslice__(self, *args)

    def __delslice__(self, i: 'std::vector< char >::difference_type', j: 'std::vector< char >::difference_type') -> "void":
        return _medfile.MEDCHAR___delslice__(self, i, j)

    def __delitem__(self, *args) -> "void":
        return _medfile.MEDCHAR___delitem__(self, *args)

    def __getitem__(self, *args) -> "std::vector< char >::value_type const &":
        return _medfile.MEDCHAR___getitem__(self, *args)

    def __setitem__(self, *args) -> "void":
        return _medfile.MEDCHAR___setitem__(self, *args)

    def pop(self) -> "std::vector< char >::value_type":
        return _medfile.MEDCHAR_pop(self)

    def append(self, x: 'std::vector< char >::value_type const &') -> "void":
        return _medfile.MEDCHAR_append(self, x)

    def empty(self) -> "bool":
        return _medfile.MEDCHAR_empty(self)

    def size(self) -> "std::vector< char >::size_type":
        return _medfile.MEDCHAR_size(self)

    def swap(self, v: 'MEDCHAR') -> "void":
        return _medfile.MEDCHAR_swap(self, v)

    def begin(self) -> "std::vector< char >::iterator":
        return _medfile.MEDCHAR_begin(self)

    def end(self) -> "std::vector< char >::iterator":
        return _medfile.MEDCHAR_end(self)

    def rbegin(self) -> "std::vector< char >::reverse_iterator":
        return _medfile.MEDCHAR_rbegin(self)

    def rend(self) -> "std::vector< char >::reverse_iterator":
        return _medfile.MEDCHAR_rend(self)

    def clear(self) -> "void":
        return _medfile.MEDCHAR_clear(self)

    def get_allocator(self) -> "std::vector< char >::allocator_type":
        return _medfile.MEDCHAR_get_allocator(self)

    def pop_back(self) -> "void":
        return _medfile.MEDCHAR_pop_back(self)

    def erase(self, *args) -> "std::vector< char >::iterator":
        return _medfile.MEDCHAR_erase(self, *args)

    def __init__(self, *args):
        this = _medfile.new_MEDCHAR(*args)
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this

    def push_back(self, x: 'std::vector< char >::value_type const &') -> "void":
        return _medfile.MEDCHAR_push_back(self, x)

    def front(self) -> "std::vector< char >::value_type const &":
        return _medfile.MEDCHAR_front(self)

    def back(self) -> "std::vector< char >::value_type const &":
        return _medfile.MEDCHAR_back(self)

    def assign(self, n: 'std::vector< char >::size_type', x: 'std::vector< char >::value_type const &') -> "void":
        return _medfile.MEDCHAR_assign(self, n, x)

    def resize(self, *args) -> "void":
        return _medfile.MEDCHAR_resize(self, *args)

    def insert(self, *args) -> "void":
        return _medfile.MEDCHAR_insert(self, *args)

    def reserve(self, n: 'std::vector< char >::size_type') -> "void":
        return _medfile.MEDCHAR_reserve(self, n)

    def capacity(self) -> "std::vector< char >::size_type":
        return _medfile.MEDCHAR_capacity(self)

    def __iadd__(self, value: 'MEDCHAR') -> "std::vector< char,std::allocator< char > > &":
        return _medfile.MEDCHAR___iadd__(self, value)

    def __add__(self, value: 'MEDCHAR') -> "std::vector< char,std::allocator< char > >":
        return _medfile.MEDCHAR___add__(self, value)

    def __isub__(self, value: 'MEDCHAR') -> "std::vector< char,std::allocator< char > > &":
        return _medfile.MEDCHAR___isub__(self, value)

    def __sub__(self, value: 'MEDCHAR') -> "std::vector< char,std::allocator< char > >":
        return _medfile.MEDCHAR___sub__(self, value)

    def __imul__(self, value: 'MEDCHAR') -> "std::vector< char,std::allocator< char > > &":
        return _medfile.MEDCHAR___imul__(self, value)

    def __mul__(self, value: 'MEDCHAR') -> "std::vector< char,std::allocator< char > >":
        return _medfile.MEDCHAR___mul__(self, value)

    def __itruediv__(self, *args):
        return _medfile.MEDCHAR___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medfile.MEDCHAR___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value: 'MEDCHAR') -> "bool":
        return _medfile.MEDCHAR___le__(self, value)

    def __lt__(self, value: 'MEDCHAR') -> "bool":
        return _medfile.MEDCHAR___lt__(self, value)

    def __gt__(self, value: 'MEDCHAR') -> "bool":
        return _medfile.MEDCHAR___gt__(self, value)

    def __ge__(self, value: 'MEDCHAR') -> "bool":
        return _medfile.MEDCHAR___ge__(self, value)

    def __eq__(self, value: 'MEDCHAR') -> "bool":
        return _medfile.MEDCHAR___eq__(self, value)

    def __ne__(self, value: 'MEDCHAR') -> "bool":
        return _medfile.MEDCHAR___ne__(self, value)
    __swig_destroy__ = _medfile.delete_MEDCHAR
    __del__ = lambda self: None
MEDCHAR_swigregister = _medfile.MEDCHAR_swigregister
MEDCHAR_swigregister(MEDCHAR)


MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


def MEDfileOpen(filename: 'char const *const', accessmode: 'med_access_mode const') -> "char const *const":
    """
    MEDfileOpen(filename, accessmode) -> med_idt

    Parameters
    ----------
    filename: char const *const
    accessmode: enum med_access_mode const

    """
    return _medfile.MEDfileOpen(filename, accessmode)

def MEDfileVersionOpen(filename: 'char const *const', accessmode: 'med_access_mode const', major: 'med_int const', minor: 'med_int const', release: 'med_int const') -> "char const *const":
    """
    MEDfileVersionOpen(filename, accessmode, major, minor, release) -> med_idt

    Parameters
    ----------
    filename: char const *const
    accessmode: enum med_access_mode const
    major: med_int const
    minor: med_int const
    release: med_int const

    """
    return _medfile.MEDfileVersionOpen(filename, accessmode, major, minor, release)

def MEDfileExist(filename: 'char const *const', accessmode: 'med_access_mode const') -> "char const *const, med_bool *, med_bool *":
    """
    MEDfileExist(filename, accessmode) -> med_err

    Parameters
    ----------
    filename: char const *const
    accessmode: enum med_access_mode const

    """
    return _medfile.MEDfileExist(filename, accessmode)

def MEDfileName(fid: 'med_idt') -> "med_int":
    """MEDfileName(fid) -> str"""
    return _medfile.MEDfileName(fid)

def MEDfileClose(fid: 'med_idt') -> "med_err":
    """
    MEDfileClose(fid) -> med_err

    Parameters
    ----------
    fid: med_idt

    """
    return _medfile.MEDfileClose(fid)

def MEDfileCommentWr(fid: 'med_idt const', comment: 'char const *const') -> "char const *const":
    """
    MEDfileCommentWr(fid, comment) -> med_err

    Parameters
    ----------
    fid: med_idt const
    comment: char const *const

    """
    return _medfile.MEDfileCommentWr(fid, comment)

def MEDfileCommentRd(fid: 'med_idt const') -> "char *const":
    """
    MEDfileCommentRd(fid) -> med_err

    Parameters
    ----------
    fid: med_idt const

    """
    return _medfile.MEDfileCommentRd(fid)

def MEDfileCompatibility(filename: 'char const *const') -> "char const *const, med_bool *, med_bool *":
    """
    MEDfileCompatibility(filename) -> med_err

    Parameters
    ----------
    filename: char const *const

    """
    return _medfile.MEDfileCompatibility(filename)

def MEDfileNumVersionRd(fid: 'med_idt const') -> "med_int *const, med_int *const, med_int *const":
    """
    MEDfileNumVersionRd(fid) -> med_err

    Parameters
    ----------
    fid: med_idt const

    """
    return _medfile.MEDfileNumVersionRd(fid)

def MEDfileStrVersionRd(fid: 'med_idt const') -> "char *const":
    """
    MEDfileStrVersionRd(fid) -> med_err

    Parameters
    ----------
    fid: med_idt const

    """
    return _medfile.MEDfileStrVersionRd(fid)

def MEDfileObjectsMount(fid: 'med_idt const', filename: 'char const *const', medclass: 'med_class const') -> "char const *const":
    """
    MEDfileObjectsMount(fid, filename, medclass) -> med_idt

    Parameters
    ----------
    fid: med_idt const
    filename: char const *const
    medclass: enum med_class const

    """
    return _medfile.MEDfileObjectsMount(fid, filename, medclass)

def MEDfileObjectsMountById(fid: 'med_idt const', chfid: 'med_idt const', chpath: 'char const *const', medclass: 'med_class const') -> "char const *const":
    """
    MEDfileObjectsMountById(fid, chfid, chpath, medclass) -> med_idt

    Parameters
    ----------
    fid: med_idt const
    chfid: med_idt const
    chpath: char const *const
    medclass: enum med_class const

    """
    return _medfile.MEDfileObjectsMountById(fid, chfid, chpath, medclass)

def MEDfileObjectsUnmount(fid: 'med_idt const', mid: 'med_idt const', medclass: 'med_class const') -> "med_err":
    """
    MEDfileObjectsUnmount(fid, mid, medclass) -> med_err

    Parameters
    ----------
    fid: med_idt const
    mid: med_idt const
    medclass: enum med_class const

    """
    return _medfile.MEDfileObjectsUnmount(fid, mid, medclass)

def MEDfileObjectExist(fid: 'med_idt const', medclass: 'med_class const', objectname: 'char const *const') -> "char const *const, med_bool *":
    """
    MEDfileObjectExist(fid, medclass, objectname) -> med_err

    Parameters
    ----------
    fid: med_idt const
    medclass: enum med_class const
    objectname: char const *const

    """
    return _medfile.MEDfileObjectExist(fid, medclass, objectname)
# This file is compatible with both classic and new-style classes.


